@@ -1,7 +1,7 @@
 /*
  * segatex_editor SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2008 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #include <qapplication.h>
 #include <qsplashscreen.h>
+#include <qtextcodec.h>
 
 #include "mainwindow.h"
 
@@ -27,6 +28,14 @@ int main(int argc, char *argv[])
 {
     
 	QApplication app(argc, argv);
+	QTranslator appTranslator;
+	//appTranslator.load(QString("app_") + QTextCodec::locale(),
+	//			qApp->applicationDirPath());
+	appTranslator.load(QString("segatex_") + QTextCodec::locale(),
+				"/root/segatex");
+	//appTranslator.load("segatex_jp",
+	//			"/root/segatex");
+	app.installTranslator(&appTranslator);
 	QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
 	splash->show();
 	splash->message(QObject::tr("Setting up the main window..."),
@@ -36,10 +45,11 @@ int main(int argc, char *argv[])
 	app.setMainWidget(&mainWin);
 
 	if (argc > 1) {
-	for (int i = 1; i < argc; ++i)
-	    mainWin.openFile(argv[i]);
+		for (int i = 1; i < argc; ++i){
+		    mainWin.openFile(argv[i]);
+		}
 	} else {
-	mainWin.newFile();
+		mainWin.newFile();
 	}
 
 	mainWin.show();
