@@ -61,6 +61,8 @@
 #include "semanage_core_boolean_process.h"
 #include "autorelabel.h"
 #include "policygeneration.h"
+#include "aureport.h"
+#include "ausearch.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -102,6 +104,8 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	semanage_core_boolean_process_o = 0;
 	autorelabel_process_o = 0;
 	policygeneration_process_o = 0;
+	aureport_o = 0;
+	ausearch_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -117,7 +121,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-5.00"));
+	setCaption(tr("segatex-5.40"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -456,6 +460,16 @@ void MainWindow::createActions()
 	policygeneration_processAct->setStatusTip(tr("Generate policy_module."));
 	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(policygeneration_process()));
 	connect(policygeneration_processAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	aureportAct = new QAction(tr("&Aureport"), 0, this);
+	aureportAct->setStatusTip(tr("Aureport"));
+	connect(aureportAct, SIGNAL(activated()), this, SLOT(aureport()));
+	connect(aureportAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	ausearchAct = new QAction(tr("&Ausearch"), 0, this);
+	aureportAct->setStatusTip(tr("Ausearch"));
+	connect(ausearchAct, SIGNAL(activated()), this, SLOT(ausearch()));
+	connect(ausearchAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -516,11 +530,13 @@ void MainWindow::createMenus()
 	selpaw_interface_csvAct->addTo(refineMenu);
 
 	//newly added
-	policyMenu = new QPopupMenu(this);
+	auditMenu = new QPopupMenu(this);
+	segatex_coreAct->addTo(auditMenu);
+	audit2allowAct->addTo(auditMenu);
+	aureportAct->addTo(auditMenu);
+	ausearchAct->addTo(auditMenu);
 
-	segatex_coreAct->addTo(policyMenu);
-	audit2allowAct->addTo(policyMenu);
-	//selinuxYumAct->addTo(policyMenu);
+	policyMenu = new QPopupMenu(this);
 	selinuxYumProcessAct->addTo(policyMenu);
 	enforcingAct->addTo(policyMenu);
 	check_selinuxAct->addTo(policyMenu);
@@ -547,6 +563,7 @@ void MainWindow::createMenus()
 
 	//newly added-3:add action to menubar
 	menuBar()->insertSeparator();
+	menuBar()->insertItem(tr("&Audit"), auditMenu);
 	menuBar()->insertItem(tr("&Policy"), policyMenu);
 	menuBar()->insertItem(tr("&Modules"), manageMenu);
 	menuBar()->insertItem(tr("&Semanage"), semanageMenu);
@@ -557,7 +574,7 @@ void MainWindow::createMenus()
 	menuBar()->insertItem(tr("&Refine"), refineMenu);
 
 	menuBar()->insertSeparator();
-	menuBar()->insertItem(tr("Rel&abel"), autorelabelMenu);
+	menuBar()->insertItem(tr("Re&label"), autorelabelMenu);
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("&Help"), helpMenu);
@@ -894,10 +911,10 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-5.00</h2>"
+		tr("<h2>segatex-5.40</h2>"
 		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
-		"<p>segatex_suite is a SELinux tool"
+		"<p>segatex is a SELinux tool"
 		"<p><b>written with Qt</b>."));
 }
 //newly added
@@ -918,6 +935,8 @@ void MainWindow::howtouse()
 		" You can generate brand-new policy module."
 		" You can generate interfaced policy,by "
 		" Analize audit.log-generate policy."
+		" You can aureport."
+		" You can ausearch."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push Parselines,Selpaw,Refine"
 		" one by one orderly."
@@ -1148,3 +1167,21 @@ void MainWindow::policygeneration_process()
 	policygeneration_process_o->raise();
 	policygeneration_process_o->setActiveWindow();
 }
+void MainWindow::aureport()
+{
+	if(!aureport_o) {
+		aureport_o = new Aureport(this);
+	}
+	aureport_o->show();
+	aureport_o->raise();
+	aureport_o->setActiveWindow();
+}
+void MainWindow::ausearch()
+{
+	if(!ausearch_o) {
+		ausearch_o = new Ausearch(this);
+	}
+	ausearch_o->show();
+	ausearch_o->raise();
+	ausearch_o->setActiveWindow();
+}
